@@ -43,6 +43,7 @@ case "$1" in
         sqlite3 "$VAR_DIR/$USER_DB" < /usr/share/doc/benno-web/contrib/db-create.sql 2>/dev/null
         #
         sqlite3 "$VAR_DIR/$USER_DB" < /usr/share/doc/benno-web/contrib/db-update_2.0.1.sql 2>/dev/null
+        #
         set -e
 
         chown $WWW_USER "$VAR_DIR/$USER_DB"
@@ -85,6 +86,17 @@ case "$1" in
             cat /etc/benno/rest.secret >> /etc/benno-web/rest.conf
         fi
 
+        # Auth.d
+        if [ ! -d /etc/benno-web/auth.d ];then
+            mkdir /etc/benno-web/auth.d
+        fi
+        if [ ! -f /etc/benno-web/auth.conf ];then
+            echo "# benno_auth.d configuration file" >> /etc/benno-web/auth.conf
+            echo "#"                                 >> /etc/benno-web/auth.conf
+            echo "module_dir=/etc/benno-web/auth.d"  >> /etc/benno-web/auth.conf
+            echo ""                                  >> /etc/benno-web/auth.conf
+        fi
+
     ;;
 
     abort-upgrade|abort-remove|abort-deconfigure)
