@@ -672,7 +672,7 @@ class Application extends ApplicationConfig
      * @access public
      * @param string | array $params and values array
      */
-    function redirect ($action,$plist=array())
+   function redirect ($action,$plist=array())
     {
         if ($this->getConfig('URL_SESSIONID') == 'ENABLED') {
             $sidprefix = session_name().'='.session_id().'&';
@@ -692,27 +692,42 @@ class Application extends ApplicationConfig
             $this->log("------------------------------------------",2,'SPAF2/App');
         }
 
+        // HTTP HOST
+        if (isset($_SERVER['HTTP_X_FORWARDED_HOST'])) {
+            $http_host = $_SERVER['HTTP_X_FORWARDED_HOST'];
+        }
+        else {
+            $http_host = $_SERVER['HTTP_HOST'];
+        }
+        // HTTP PROTOCOL
+        if (isset($_SERVER['HTTP_X_FORWARDED_PROTO'])) {
+            $http_proto = $_SERVER['HTTP_X_FORWARDED_PROTO'];
+            $http_proto = $http_proto.'://';
+        }
+        elseif (isset($_SERVER['HTTPS'])) {
+            $http_proto = 'https://';
+        }    
+        else {            
+            $http_proto = 'http://';
+        }
+        // HTTP PORT
+        if (isset($_SERVER['HTTP_X_FORWARDED_PORT'])) {
+            $http_port = $_SERVER['HTTP_X_FORWARDED_PORT'];
+        }
+        else {
+            $http_port = '';
+        }
+
+        // HTTP CONFIGURATION
         if ($redirect_base = $this->getConfig('REDIRECT_BASE')) {
             $location = 'Location: '.$redirect_base.$_SERVER['SCRIPT_NAME']."?$params";
         }
-        elseif (isset($_SERVER['HTTPS'])) {
-            $PROTO = 'https://';
-            $http_host = $_SERVER['HTTP_HOST'];
-            if (!preg_match('/^[a-z\d:\.](-*[a-z\d:\.])*$/',$http_host)) {
-                $this->log('Exit while invalid hostname for redirect: '.$http_host,0,'SPAF2/App');
-                exit;
+        else {
+            if ($http_port) {
+                $http_host = $http_host.':'.$http_port;
             }
-            $location = 'Location: '.$PROTO.$http_host.$_SERVER['SCRIPT_NAME']."?$params";
-        }    
-        else {            
-            $PROTO = 'http://';
-            $http_host = $_SERVER['HTTP_HOST'];
-            if (!preg_match('/^[a-z\d:\.](-*[a-z\d:\.])*$/',$http_host)) {
-                $this->log('Exit while invalid hostname given for redirect: '.$http_host,0,'SPAF2/App');
-                exit;
-            }
-            $location = 'Location: '.$PROTO.$http_host.$_SERVER['SCRIPT_NAME']."?$params";
-        } 
+            $location = 'Location: '.$http_proto.$http_host.$_SERVER['SCRIPT_NAME']."?$params";
+        }
 
         header($location);
         exit();
