@@ -36,26 +36,27 @@ require_once 'model/DateConvert.php';
 require_once 'model/Filter.php';
 require_once 'model/AppState.php';
 
-$authscript  = $App->getConfig('EXTERNAL_AUTH');
+$authscript  = $App->getConfig('EXTERNAL_AUTH','/usr/lib/benno-web/benno_sqliteauth');
 
 $login = $App->getParam('login');
 
 $userid = $login['username'];
-$pass = $login['password'];
+$passwd = $login['password'];
 
-if (! $pass) {
+if (! $passwd) {
     $App->redirect('default',array('MSG'=>'ERR_NOPASS'));
 }
 
 $User = new User($userid);
 try {
-    if ($authscript) {
-        $User->loadExternal($authscript,$pass);
+    if ($authscript && is_readable($authscript)) {
+        $User->loadExternal($authscript,$passwd);
     }
     else {
+        $App->log("Cannot read \"$authscript\". Fallback authentication.");
         $User->load();
         // check authentication
-        if ($User->password != md5($pass)) {
+        if ($User->password != md5($passwd)) {
             // Authentication error -> redirect to login
             $App->log('Authentication of '.$User->id.' failed');
             $App->redirect('default',array('MSG'=>'ERR_AUTH'));
