@@ -91,6 +91,10 @@ class UserDA extends Persistence
             array_push($this->addresses,$row['address']);
         }
 
+        if ($this->role == 'ADMIN' || $this->role == 'REVISOR') {
+            array_unshift($this->archive,'SYSDATA');
+        }
+
         return FALSE;
     }
 
@@ -256,6 +260,10 @@ class UserDA extends Persistence
             error_log("[User::external] ARCHIVE not set by external auth");
             throw new Exception('ERR_ARCHIVE');
         }
+
+        if ($this->role == 'ADMIN' || $this->role == 'REVISOR') {
+            array_unshift($this->archive,'SYSDATA');
+        }
         return FALSE;
     }
 
